# Datastream example

This example demonstrates reading a data stream, via a long poll.

Note that some browsers buffer data from a stream before sending it to the screen. In that case "nothing" seems to happens until the buffer limit is reached.

When the datasource is located on an external server, the datasource must enable cross domain scripting (Access-Control-Allow-Origin must be set on the server side).